==> prestashop_1.5.0.15.zip: prestashop/modules/blockreinsurance/translations/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_0b65f7c6060801bc4ef8ac49eecf44d2'] = 'Blocco rassicurativo';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_0cdd94b6a03ddcd4014822a822b675eb'] = 'Aggiungi un blocco per visualizzaare maggiori informazioni per rassicurare I tuoi clienti.';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_31c78485b2a9d9151e0cde196934aad8'] = 'Errore durante il salvataggio';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configurazione aggiornata';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_4fe64a0798179f063eb69d406c4d5038'] = 'Nuovo blocco rassicurazioni';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_461900b74731e07320ca79366df3e809'] = 'Immagine:';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_ed2fc2838f7edb7607dd1cd19f3a82e0'] = 'Testo:';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_38fb7d24e0d60a048f540ecb18e13376'] = 'Salva';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_c9cc8cce247e49bae79f15173ce97354'] = 'Salva';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_630f6dc397fe74e52d5189e2c80f282b'] = 'Ritorna all\'elenco';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_490aa6e856ccf208a054389e47ce0d06'] = 'ID';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_9dffbf69ffba8bc38bc4e01abf4b1675'] = 'Testo';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_23498d91b6017e5d7f4ddde70daba286'] = 'ID negozio';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_ef61fb324d729c341ea8ab9901e23566'] = 'Aggiungi nuovo';

==> prestashop_1.5.1.0.zip: prestashop/modules/blockreinsurance/translations/it.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_0b65f7c6060801bc4ef8ac49eecf44d2'] = 'Blocco rassicurativo';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_0cdd94b6a03ddcd4014822a822b675eb'] = 'Aggiungi un blocco per visualizzaare maggiori informazioni per rassicurare I tuoi clienti.';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_31c78485b2a9d9151e0cde196934aad8'] = 'Errore durante il salvataggio';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configurazione aggiornata';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_4fe64a0798179f063eb69d406c4d5038'] = 'Nuovo blocco rassicurazioni';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_461900b74731e07320ca79366df3e809'] = 'Immagine:';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_ed2fc2838f7edb7607dd1cd19f3a82e0'] = 'Testo:';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_38fb7d24e0d60a048f540ecb18e13376'] = 'Salva';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_c9cc8cce247e49bae79f15173ce97354'] = 'Salva';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_630f6dc397fe74e52d5189e2c80f282b'] = 'Ritorna all\'elenco';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_490aa6e856ccf208a054389e47ce0d06'] = 'ID';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_9dffbf69ffba8bc38bc4e01abf4b1675'] = 'Testo';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_23498d91b6017e5d7f4ddde70daba286'] = 'ID negozio';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_ef61fb324d729c341ea8ab9901e23566'] = 'Aggiungi nuovo';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_212ec5c1ad6e7811c9ceca38b29f0aff'] = 'Rimborso';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_488ec823efaa6f1a629d149ecc0eacf9'] = 'Scambio in negozio';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_eb656114f93f0a44609969d05de3673c'] = 'Pagamento alla consegna.';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_b00b85425e74ed2c85dc3119b78ff2c3'] = 'È gratis';
$_MODULE['<{blockreinsurance}prestashop>blockreinsurance_1bb4719012d79b9dba021844dd57f116'] = 'Pagamento 100% sicuro';
